package com.isu.gaswellwatch.service;

import java.util.List;
import java.util.Collection;

import com.isu.gaswellwatch.dto.BlockCreateRequest;
import com.isu.gaswellwatch.dto.BlockEditRequest;
import com.isu.gaswellwatch.vo.BlockPageQuery;
import com.isu.gaswellwatch.vo.BlockVO;
import com.isu.gaswellwatch.entity.Block;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

/**
 * 区块Service接口
 *
 * @author scwsl
 * @date 2024-11-17
 */
public interface BlockService extends IService<Block> {
    /**
     * 查询区块
     *
     * @param id 区块主键
     * @return 区块
     */
    BlockVO selectBlockById(Long id);

    /**
     * 查询区块列表
     *
     * @param block 区块
     * @return 区块集合
     */
    List<BlockVO> selectBlockList(Block block);

    /**
     * 分页查询区块列表
     *
     * @param query 查询条件
     * @return 区块
     */
    Page<BlockVO> pageForQuery(BlockPageQuery query);

    /**
     * 新增区块
     *
     * @param blockCreateRequest 区块
     * @return 结果
     */
    int insertBlock(BlockCreateRequest blockCreateRequest);

    /**
     * 修改区块
     *
     * @param blockEditRequest 区块
     * @return 结果
     */
    int updateBlock(BlockEditRequest blockEditRequest);

    /**
     * 删除区块信息
     *
     * @param id 区块主键
     * @return 结果
     */
    int deleteBlockById(Long id);

    /**
     * 批量删除区块
     *
     * @param ids 需要删除的区块主键集合
     * @return 结果
     */
    int deleteBlockByIds(Collection<Long> ids);

}
