package com.isu.gaswellwatch.service.impl;

import java.util.Collection;
import java.util.List;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.isu.gaswellwatch.dto.BlockCreateRequest;
import com.isu.gaswellwatch.dto.BlockEditRequest;
import com.isu.gaswellwatch.vo.BlockPageQuery;
import com.isu.gaswellwatch.vo.BlockVO;
import com.isu.gaswellwatch.dao.BlockDao;
import com.isu.gaswellwatch.entity.Block;
import com.isu.gaswellwatch.service.BlockService;
import com.isu.gaswellwatch.mapper.BlockMapper;
import org.mapstruct.factory.Mappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

/**
 * 区块Service业务层处理
 * 
 * @author scwsl
 * @date 2024-11-17
 */
@Service
@RequiredArgsConstructor
@Transactional(readOnly = true)
public class BlockServiceImpl  extends ServiceImpl<BlockDao, Block> implements BlockService {

    private final BlockDao blockDao;
    private final BlockMapper blockMapper = Mappers.getMapper(BlockMapper.class);

    /**
     * 查询区块
     * 
     * @param id 区块主键
     * @return 区块
     */
    @Override
    public BlockVO selectBlockById(Long id) {
        return blockMapper.toPageVO(blockDao.selectBlockById(id));
    }

    /**
     * 查询区块列表
     * 
     * @param block 区块
     * @return 区块
     */
    @Override
    public List<BlockVO> selectBlockList(Block block) {
        return blockMapper.toPageVO(blockDao.selectBlockList(block));
    }

    /**
     * 分页查询区块列表
     *
     * @param query 查询条件
     * @return 区块
     */
    @Override
    public Page<BlockVO> pageForQuery(BlockPageQuery query){
        return blockDao.pageForQuery(new Page<>(query.getCurrentPage(), query.getPageSize()), query);
    }

    /**
     * 新增区块
     * 
     * @param blockCreateRequest 区块
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Throwable.class)
    public int insertBlock(BlockCreateRequest blockCreateRequest) {
        return blockDao.insertBlock(blockMapper.create(blockCreateRequest));
    }

    /**
     * 修改区块
     * 
     * @param blockEditRequest 区块
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Throwable.class)
    public int updateBlock(BlockEditRequest blockEditRequest) {
        Block block = blockDao.selectBlockById(blockEditRequest.getId());
        blockMapper.copyToEntity(blockEditRequest, block);
        return blockDao.updateBlock(block);
    }

    /**
     * 删除区块信息
     * 
     * @param id 区块主键
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Throwable.class)
    public int deleteBlockById(Long id) {
        return blockDao.deleteBlockById(id);
    }

    /**
     * 批量删除删除区块信息
     *
     * @param ids 区块主键
     * @return 数量
     */
    @Override
    @Transactional(rollbackFor = Throwable.class)
    public int deleteBlockByIds(Collection<Long> ids) {
        return blockDao.deleteBlockByIds(ids);
    }

}
